{
  # Snowfall Lib provides a customized `lib` instance with access to your flake's library
  # as well as the libraries available from your flake's inputs.
  lib,
  # An instance of `pkgs` with your overlays and packages applied is also available.
  pkgs,
  # You also have access to your flake's inputs.
  inputs,

  # Additional metadata is provided by Snowfall Lib.
  system, # The system architecture for this host (eg. `x86_64-linux`).
  target, # The Snowfall Lib target for this system (eg. `x86_64-iso`).
  format, # A normalized name for the system target (eg. `iso`).
  virtual, # A boolean to determine whether this system is a virtual target using nixos-generators.
  systems, # An attribute map of your defined hosts.

  # All other arguments come from the module system.
  config,
  ...
}:

let
  cfg = config.modules.kitty;
in
{
  options.modules.kitty = {
    enable = lib.mkOption { default = false; };
  };

  config = lib.mkIf cfg.enable {
    programs.kitty = {
      enable = true;
      shellIntegration.enableFishIntegration = true;
      theme = "Catppuccin-Mocha";
      settings = {
        enable_audio_bell = false;
        confirm_os_window_close = 0; # no ask on quit
      };
      font = {
        package = pkgs.dejavu_fonts;
        name = "DejaVu Sans";
        size = 12;
      };
    };
    home.shellAliases = {
      y = "ya"; # Yazi shell wrapper (cd on quit)
    };

    systemd.user.sessionVariables.TERMINAL = "kitty";
  };
}
